@@ -20,9 +20,9 @@
 #ifndef INSERTSHORTURLPLUGINEDITOR_H
 #define INSERTSHORTURLPLUGINEDITOR_H
 
-#include <messagecomposer/plugineditor.h>
+#include <MessageComposer/PluginEditor>
 
-#include <messagecomposer/plugineditorinterface.h>
+#include <MessageComposer/PluginEditorInterface>
 #include <QVariant>
 
 class InsertShorturlPluginEditor : public MessageComposer::PluginEditor
