@@ -32,6 +32,7 @@
 
 #include <prison/Prison>
 
+#include <QGuiApplication>
 #include <QUrl>
 #include <QImage>
 #include <QMetaProperty>
@@ -39,10 +40,11 @@
 static bool isPkPassContent(KMime::Content *content)
 {
     const auto ct = content->contentType(false);
-    if (ct && ct->mimeType() == "application/vnd.apple.pkpass") {
+    const QByteArray mimetype = ct ? ct->mimeType() : QByteArray();
+    if (mimetype == "application/vnd.apple.pkpass") {
         return true;
     }
-    if (ct && ct->mimeType() != "application/octet-stream" && ct->mimeType() != "application/zip") {
+    if (mimetype != "application/octet-stream" && mimetype != "application/zip") {
         return false;
     }
     if (ct && ct->name().endsWith(QLatin1String("pkpass"))) {
@@ -108,6 +110,13 @@ public:
             pass->setProperty("footerUrl", QUrl::fromLocalFile(fileName));
             mp->nodeHelper()->addTempFile(fileName);
         }
+        const auto thumbnail = pass->thumbnail();
+        if (!thumbnail.isNull()) {
+            const QString fileName = dir + QStringLiteral("/thumbnail.png");
+            thumbnail.save(fileName);
+            pass->setProperty("thumbnailUrl", QUrl::fromLocalFile(fileName));
+            mp->nodeHelper()->addTempFile(fileName);
+        }
 
         const auto barcodes = pass->barcodes();
         if (!barcodes.isEmpty()) {
@@ -126,10 +135,9 @@ public:
 
             if (code) {
                 code->setData(barcode.message());
-                code->toImage(code->minimumSize()); // minimumSize is only available after we rendered once...
 
                 const QString fileName = dir + QStringLiteral("/barcode.png");
-                code->toImage(code->minimumSize()).save(fileName);
+                code->toImage(code->preferredSize(qGuiApp->devicePixelRatio())).save(fileName);
 
                 pass->setProperty("barcodeUrl", QUrl::fromLocalFile(fileName));
                 mp->nodeHelper()->addTempFile(fileName);
@@ -150,6 +158,8 @@ public:
             t = MessageViewer::MessagePartRendererManager::self()->loadByName(QStringLiteral("org.kde.messageviewer/pkpass/boardingpass.html"));
         } else if (pass->type() == KPkPass::Pass::EventTicket) {
             t = MessageViewer::MessagePartRendererManager::self()->loadByName(QStringLiteral("org.kde.messageviewer/pkpass/eventticket.html"));
+        } else if (pass->type() == KPkPass::Pass::Generic) {
+            t = MessageViewer::MessagePartRendererManager::self()->loadByName(QStringLiteral("org.kde.messageviewer/pkpass/generic.html"));
         } else {
             // unknown pass type we have no template for
             return false;
